@@ -36,6 +36,13 @@
 #define LIBOFX_H
 #include <time.h>
 
+#define LIBOFX_MAJOR_VERSION 0
+#define LIBOFX_MINOR_VERSION 9
+#define LIBOFX_MICRO_VERSION 0
+#define LIBOFX_BUILD_VERSION 0
+#define LIBOFX_VERSION_RELEASE_STRING "0.9.0"
+
+
 #ifdef __cplusplus
 #define CFCT extern "C"
 #else
@@ -45,33 +52,38 @@
 #endif
 
 #define OFX_ELEMENT_NAME_LENGTH         100
-#define OFX_SVRTID2_LENGTH             36 + 1
-#define OFX_CHECK_NUMBER_LENGTH        12 + 1
-#define OFX_REFERENCE_NUMBER_LENGTH    32 + 1
-#define OFX_FITID_LENGTH               255 + 1
-#define OFX_TOKEN2_LENGTH              36 + 1
-#define OFX_MEMO2_LENGTH               390 + 1
-#define OFX_BALANCE_NAME_LENGTH        32 + 1
-#define OFX_BALANCE_DESCRIPTION_LENGTH 80 + 1
-#define OFX_CURRENCY_LENGTH            3 + 1 /* In ISO-4217 format */
-#define OFX_BANKID_LENGTH              9 + 1
-#define OFX_BRANCHID_LENGTH            22 + 1
-#define OFX_ACCTID_LENGTH              22 + 1 
-#define OFX_ACCTKEY_LENGTH             22 + 1
-#define OFX_BROKERID_LENGTH            22 + 1
+#define OFX_SVRTID2_LENGTH             (36 + 1)
+#define OFX_CHECK_NUMBER_LENGTH        (12 + 1)
+#define OFX_REFERENCE_NUMBER_LENGTH    (32 + 1)
+#define OFX_FITID_LENGTH               (255 + 1)
+#define OFX_TOKEN2_LENGTH              (36 + 1)
+#define OFX_MEMO_LENGTH                (255 + 1)
+#define OFX_MEMO2_LENGTH               (390 + 1)
+#define OFX_BALANCE_NAME_LENGTH        (32 + 1)
+#define OFX_BALANCE_DESCRIPTION_LENGTH (80 + 1)
+#define OFX_CURRENCY_LENGTH            (3 + 1) /* In ISO-4217 format */
+#define OFX_BANKID_LENGTH              (9 + 1)
+#define OFX_BRANCHID_LENGTH            (22 + 1)
+#define OFX_ACCTID_LENGTH              (22 + 1)
+#define OFX_ACCTKEY_LENGTH             (22 + 1)
+#define OFX_BROKERID_LENGTH            (22 + 1)
 /* Must be MAX of <BANKID>+<BRANCHID>+<ACCTID>, <ACCTID>+<ACCTKEY> and <ACCTID>+<BROKERID> */
-#define OFX_ACCOUNT_ID_LENGTH OFX_BANKID_LENGTH + OFX_BRANCHID_LENGTH + OFX_ACCTID_LENGTH + 1
+#define OFX_ACCOUNT_ID_LENGTH (OFX_BANKID_LENGTH + OFX_BRANCHID_LENGTH + OFX_ACCTID_LENGTH + 1)
 #define OFX_ACCOUNT_NAME_LENGTH        255
-#define OFX_MARKETING_INFO_LENGTH      360 + 1
-#define OFX_TRANSACTION_NAME_LENGTH    32 + 1
-#define OFX_UNIQUE_ID_LENGTH           32 + 1
-#define OFX_UNIQUE_ID_TYPE_LENGTH      10 + 1
-#define OFX_SECNAME_LENGTH             32 + 1
-#define OFX_TICKER_LENGTH              32 + 1
-#define OFX_ORG_LENGTH                 32 + 1
-#define OFX_FID_LENGTH                 32 + 1
-#define OFX_USERID_LENGTH              32 + 1
-#define OFX_USERPASS_LENGTH            32 + 1
+#define OFX_MARKETING_INFO_LENGTH      (360 + 1)
+#define OFX_TRANSACTION_NAME_LENGTH    (32 + 1)
+#define OFX_UNIQUE_ID_LENGTH           (32 + 1)
+#define OFX_UNIQUE_ID_TYPE_LENGTH      (10 + 1)
+#define OFX_SECNAME_LENGTH             (32 + 1)
+#define OFX_TICKER_LENGTH              (32 + 1)
+#define OFX_ORG_LENGTH                 (32 + 1)
+#define OFX_FID_LENGTH                 (32 + 1)
+#define OFX_USERID_LENGTH              (32 + 1)
+#define OFX_USERPASS_LENGTH            (32 + 1)
+#define OFX_URL_LENGTH                 (500 + 1)
+#define OFX_APPID_LENGTH               (32)
+#define OFX_APPVER_LENGTH              (32)
+#define OFX_HEADERVERSION_LENGTH       (32)
 
 /*
 #define OFX_STATEMENT_CB               0;
@@ -95,6 +107,9 @@ CFCT LibofxContextPtr libofx_get_new_context();
 */
 CFCT int libofx_free_context( LibofxContextPtr );
 
+CFCT void libofx_set_dtd_dir(LibofxContextPtr libofx_context,
+	 	       	    const char *s);
+
 /** List of possible file formats */
 enum LibofxFileFormat{ AUTODETECT, /**< Not really a file format, used to tell the library to try to autodetect the format*/
 		     OFX, /**< Open Financial eXchange (OFX/QFX) file */
@@ -185,8 +200,8 @@ struct OfxStatusData{
    variables should all contain valid data but you should not trust the servers.
    Check if the associated *_valid is true before using them. */
   int code;            /**< Status code */
-  char* name;          /**< Code short name */
-  char* description;   /**< Code long description, from ofx_error_msg.h */
+  const char* name;          /**< Code short name */
+  const char* description;   /**< Code long description, from ofx_error_msg.h */
   int code_valid;      /**< If  code_valid is true, so is name and description
 			  (They are obtained from a lookup table) */
   /** Severity of the error */
@@ -223,7 +238,12 @@ CFCT typedef int (*LibofxProcStatusCallback)(const struct OfxStatusData data, vo
  *
  *  The OfxAccountData structure gives information about a specific account, 
  including it's type, currency and unique id. 
-*/
+ *
+ * When an OfxAccountData must be passed to functions which create OFX
+ * requests related to a specific account, it must contain all the info needed
+ * for an OFX request to identify an account.  That is:
+ * account_type, account_number, bank_id and branch_id
+ */
 struct OfxAccountData{
   
   /** @name OFX mandatory elements
@@ -259,15 +279,20 @@ struct OfxAccountData{
   char currency[OFX_CURRENCY_LENGTH]; /**< The currency is a string in ISO-4217 format */
   int currency_valid;
 
+  /** Corresponds to OFX <ACCTID> */
+  char account_number[OFX_ACCTID_LENGTH];
+  int account_number_valid;
+
+  /** Corresponds to OFX <BANKID> */
   char bank_id[OFX_BANKID_LENGTH];
   int bank_id_valid;
 
+  char broker_id[OFX_BROKERID_LENGTH];
+  int broker_id_valid;
+
   char branch_id[OFX_BRANCHID_LENGTH];
   int branch_id_valid;
 
-  char account_number[OFX_ACCTID_LENGTH];
-  int account_number_valid;
-
 };
 
 /**
@@ -504,6 +529,15 @@ char check_number[OFX_CHECK_NUMBER_LENGTH];
   int name_valid;
   char memo[OFX_MEMO2_LENGTH];/**< Extra information not included in name */
   int memo_valid;
+  double commission;/**< Commission paid to broker (investment transactions only) */
+  int commission_valid;
+  double fees;/**< Fees applied to trade (investment transactions only) */
+  int fees_valid;
+  double oldunits;     /*number of units held before stock split */
+  int oldunits_valid;
+  double newunits;     /*number of units held after stock split */
+  int newunits_valid;
+
 
   /*********** NOT YET COMPLETE!!! *********************/
 };
@@ -657,6 +691,20 @@ CFCT int libofx_proc_buffer(LibofxContextPtr ctx,
  */
 //@{
 
+/**
+ * \brief Information returned by the OFX Partner Server about a financial institution 
+ */
+
+struct OfxFiServiceInfo{
+  char fid[OFX_FID_LENGTH];
+  char org[OFX_ORG_LENGTH];
+  char url[OFX_URL_LENGTH];
+  int accountlist; /**< Whether the FI makes a list of accounts available */ 
+  int statements; /**< Whether the FI supports online statement download */
+  int billpay; /**< Whether the FI supports online bill payment */
+  int investments; /**< Whether the FI supports investments */
+};
+
  /**
  * \brief Information sufficient to log into an financial institution
  *
@@ -671,29 +719,31 @@ struct OfxFiLogin{
   char org[OFX_ORG_LENGTH];
   char userid[OFX_USERID_LENGTH];
   char userpass[OFX_USERPASS_LENGTH];
+  char header_version[OFX_HEADERVERSION_LENGTH];
+  char appid[OFX_APPID_LENGTH];
+  char appver[OFX_APPVER_LENGTH];
 };
 
-typedef enum{
-  OFX_NO_ACCOUNT=0,
-  OFX_BANK_ACCOUNT,
-  OFX_INVEST_ACCOUNT,
-  OFX_CREDITCARD_ACCOUNT,
-  OFX_INVALID_ACCOUNT
-} AccountType;
+#define OFX_AMOUNT_LENGTH (32 + 1)
+#define OFX_PAYACCT_LENGTH (32 + 1)
+#define OFX_STATE_LENGTH (5 + 1)
+#define OFX_POSTALCODE_LENGTH (11 + 1)
+#define OFX_NAME_LENGTH (32 + 1)
 
- /**
- * \brief Information sufficient to identify an account
- *
- * Contains all the info needed for an OFX request to identify an account.
- * An OfxAccountInfo must be passed to all functions which create OFX
- * requests related to a specific account.
- */
+struct OfxPayment{
+  char amount[OFX_AMOUNT_LENGTH];
+  char account[OFX_PAYACCT_LENGTH];
+  char datedue[9];
+  char memo[OFX_MEMO_LENGTH];
+};
 
-struct OfxAccountInfo{
-  char accountid[OFX_ACCOUNT_ID_LENGTH];
-  char bankid[OFX_BANKID_LENGTH];
-  char brokerid[OFX_BROKERID_LENGTH];
-  AccountType type;
+struct OfxPayee{
+  char name[OFX_NAME_LENGTH];
+  char address1[OFX_NAME_LENGTH];
+  char city[OFX_NAME_LENGTH];
+  char state[OFX_STATE_LENGTH];
+  char postalcode[OFX_POSTALCODE_LENGTH];
+  char phone[OFX_NAME_LENGTH];
 };
 
 /**
@@ -708,7 +758,7 @@ struct OfxAccountInfo{
  * @return string pointer to the request.  This is allocated via malloc(), and is the callers responsibility to free.
 */
 
-CFCT char* libofx_request_statement( const struct OfxFiLogin* fi, const struct OfxAccountInfo* account, time_t date_from );
+CFCT char* libofx_request_statement( const struct OfxFiLogin* fi, const struct OfxAccountData* account, time_t date_from );
 
 /**
  * \brief Creates an OFX account info (list) request in string form
@@ -723,6 +773,10 @@ CFCT char* libofx_request_statement( const struct OfxFiLogin* fi, const struct O
 
 CFCT char* libofx_request_accountinfo( const struct OfxFiLogin* login );
 
+CFCT char* libofx_request_payment( const struct OfxFiLogin* login, const struct OfxAccountData* account, const struct OfxPayee* payee, const struct OfxPayment* payment );
+
+CFCT char* libofx_request_payment_status( const struct OfxFiLogin* login, const char* transactionid );
+
 //@}
 
 #endif
