@@ -1,7 +1,7 @@
 /***************************************************************************
          ofx_proc_rs.cpp 
                              -------------------
-    copyright            : (C) 2002 by Benoit Grgoire
+    copyright            : (C) 2002 by Benoit Grégoire
     email                : bock@step.polymtl.ca
 ***************************************************************************/
 /**@file
@@ -82,8 +82,14 @@ OfxStatusContainer::OfxStatusContainer(LibofxContext *p_libofx_context, OfxGener
 }
 OfxStatusContainer::~OfxStatusContainer()
 {
+  message_out(DEBUG,"Entering the status's container's destructor");
+	
   libofx_context->statusCallback(data);
+
+  if ( data.server_message_valid )
+    delete [] data.server_message;
 }
+
 void OfxStatusContainer::add_attribute(const string identifier, const string value)
 {
   ErrorMsg error_msg;
@@ -112,7 +118,7 @@ void OfxStatusContainer::add_attribute(const string identifier, const string val
     }
   }
   else if((identifier=="MESSAGE")||(identifier=="MESSAGE2")){
-    data.server_message=new char[value.length()];
+    data.server_message=new char[value.length()+1];
     strcpy(data.server_message,value.c_str());
     data.server_message_valid=true;
   }
