@@ -1,7 +1,7 @@
 /***************************************************************************
                           ofxdump.cpp
                              -------------------
-    copyright            : (C) 2002 by Benoit Grgoire
+    copyright            : (C) 2002 by Benoit Grégoire
     email                : bock@step.polymtl.ca
 ***************************************************************************/
 /**@file
@@ -33,6 +33,7 @@
 #include "libofx.h"
 #include <stdio.h>		/* for printf() */
 #include <config.h>		/* Include config constants, e.g., VERSION TF */
+#include <errno.h>
 
 #include "cmdline.h" /* Gengetopt generated parser */
 
@@ -141,9 +142,21 @@ int ofx_proc_transaction_cb(struct OfxTransactionData data, void * transaction_d
   if(data.units_valid==true){
     cout<<"    # of units: "<<setiosflags(ios::fixed)<<setiosflags(ios::showpoint)<<setprecision(2)<<data.units<<"\n";
   }
+  if(data.oldunits_valid==true){
+    cout<<"    # of units before split: "<<setiosflags(ios::fixed)<<setiosflags(ios::showpoint)<<setprecision(2)<<data.oldunits<<"\n";
+  }
+  if(data.newunits_valid==true){
+    cout<<"    # of units after split: "<<setiosflags(ios::fixed)<<setiosflags(ios::showpoint)<<setprecision(2)<<data.newunits<<"\n";
+  }
   if(data.unitprice_valid==true){
     cout<<"    Unit price: "<<setiosflags(ios::fixed)<<setiosflags(ios::showpoint)<<setprecision(2)<<data.unitprice<<"\n";
   }
+  if(data.fees_valid==true){
+    cout<<"    Fees: "<<setiosflags(ios::fixed)<<setiosflags(ios::showpoint)<<setprecision(2)<<data.fees<<"\n";
+  }
+  if(data.commission_valid==true){
+    cout<<"    Commission: "<<setiosflags(ios::fixed)<<setiosflags(ios::showpoint)<<setprecision(2)<<data.commission<<"\n";
+  }
   if(data.fi_id_valid==true){
     cout<<"    Financial institution's ID for this transaction: "<<data.fi_id<<"\n";
   }
@@ -309,6 +322,15 @@ int ofx_proc_account_cb(struct OfxAccountData data, void * account_data)
     cout<<"    Currency: "<<data.currency<<"\n";
   }
 
+  if (data.bank_id_valid)
+    cout<<"    Bank ID: "<<data.bank_id << endl;;
+
+  if (data.branch_id_valid)
+    cout<<"    Branch ID: "<<data.branch_id << endl;
+
+  if (data.account_number_valid)
+    cout<<"    Account #: "<<data.account_number << endl;
+
   cout<<"\n";
   return 0;
 }//end ofx_proc_account()
@@ -372,21 +394,26 @@ int main (int argc, char *argv[])
   args_info.msg_info_flag ? ofx_INFO_msg = true : ofx_INFO_msg = false;
   args_info.msg_status_flag ? ofx_STATUS_msg = true : ofx_STATUS_msg;
 
+  bool skiphelp = false;
+  
   if(args_info.list_import_formats_given)
     {
+      skiphelp = true;
       cout <<"The supported file formats for the 'input-file-format' argument are:"<<endl;
       for(int i=0; LibofxImportFormatList[i].format!=LAST; i++)
 	{
 	  cout <<"     "<<LibofxImportFormatList[i].description<<endl;
 	}
     }
-
+		  
   LibofxContextPtr libofx_context = libofx_get_new_context();
 
   //char **inputs ; /* unamed options */
   //unsigned inputs_num ; /* unamed options number */
   if (args_info.inputs_num  > 0)
     {
+      const char* filename = args_info.inputs[0];
+
 
       ofx_set_statement_cb(libofx_context, ofx_proc_statement_cb, 0);
       ofx_set_account_cb(libofx_context, ofx_proc_account_cb, 0);
@@ -398,7 +425,7 @@ int main (int argc, char *argv[])
       /** @todo currently, only the first file is processed as the library can't deal with more right now.*/
       if(args_info.inputs_num  > 1)
         {
-          cout << "Sorry, currently, only the first file is processed as the library can't deal with more right now.  The followinf files were ignored:"<<endl;
+          cout << "Sorry, currently, only the first file is processed as the library can't deal with more right now.  The following files were ignored:"<<endl;
           for ( unsigned i = 1 ; i < args_info.inputs_num ; ++i )
             {
               cout << "file: " << args_info.inputs[i] << endl ;
@@ -408,7 +435,8 @@ int main (int argc, char *argv[])
     }
   else
     {
-
+      if ( !skiphelp )
+        cmdline_parser_print_help();
     }
   return 0;
 }
